==> beyondtrust_bips_library-1.21.0-py3-none-any.whl: secrets_safe_library/mixins.py <==
"""
Mixin classes for Secrets Safe Library.
Optional classes to extend APIObject functionality.

These mixins need to be used with APIObject class.
"""

import logging

from secrets_safe_library import utils


class ListMixin:
    """
    Mixin class to add list functionality.
    """

    def list(self) -> list:
        """
        Generic listing function.

        Returns:
            list: List of elements for defined endpoint.
        """

        utils.print_log(
            self._logger, f"Calling list endpoint: {self.endpoint}", logging.DEBUG
        )
        response = self._run_get_request(self.endpoint)

        return response.json()


class GetByIdMixin:
    """
    Mixin class to add get by ID functionality.
    """

    def get_by_id(self, object_id: str) -> dict:
        """
        Generic method to get an object by ID.

        Args:
            object_id (str): The ID of the object to retrieve.

        Returns:
            dict: The object retrieved by ID.
        """
        endpoint = f"{self.endpoint}/{object_id}"

        utils.print_log(
            self._logger, f"Calling get_by_id endpoint: {endpoint}", logging.DEBUG
        )
        response = self._run_get_request(endpoint, include_api_version=False)

        return response.json()


class DeleteByIdMixin:
    """
    Mixin class to add delete by ID functionality.
    """

    def delete_by_id(self, object_id: str, expected_status_code: int = 204) -> None:
        """
        Generic method to delete an object by ID.

        Args:
            object_id (str): The ID of the object to delete.
            expected_status_code (int, optional): The expected status code for a
                successful deletion. Defaults to 204.

        Raises:
            exceptions.DeletionError: If the deletion fails.
        """
        endpoint = f"{self.endpoint}/{object_id}"

        utils.print_log(
            self._logger, f"Calling delete_by_id endpoint: {endpoint}", logging.DEBUG
        )
        self._run_delete_request(endpoint, expected_status_code=expected_status_code)

==> beyondtrust_bips_library-1.26.0-py3-none-any.whl: secrets_safe_library/mixins.py <==
"""
Mixin classes for Secrets Safe Library.
Optional classes to extend APIObject functionality.

These mixins need to be used with APIObject class.
"""

import logging

from secrets_safe_library import utils


class ListMixin:
    """
    Mixin class to add list functionality.
    """

    def list(self) -> list:
        """
        Generic listing function.

        Returns:
            list: List of elements for defined endpoint.
        """

        utils.print_log(
            self._logger, f"Calling list endpoint: {self.endpoint}", logging.DEBUG
        )
        response = self._run_get_request(self.endpoint)

        return response.json()


class GetByIdMixin:
    """
    Mixin class to add get by ID functionality.
    """

    def get_by_id(self, object_id: str, include_api_version=False) -> dict:
        """
        Generic method to get an object by ID.

        Args:
            object_id (str): The ID of the object to retrieve.
            include_api_version (bool, optional): Whether to include the API version
                in the request. Defaults to False.

        Returns:
            dict: The object retrieved by ID.
        """
        endpoint = f"{self.endpoint}/{object_id}"

        utils.print_log(
            self._logger, f"Calling get_by_id endpoint: {endpoint}", logging.DEBUG
        )
        response = self._run_get_request(
            endpoint, include_api_version=include_api_version
        )

        return response.json()


class DeleteByIdMixin:
    """
    Mixin class to add delete by ID functionality.
    """

    def delete_by_id(self, object_id: str, expected_status_code: int = 204) -> None:
        """
        Generic method to delete an object by ID.

        Args:
            object_id (str): The ID of the object to delete.
            expected_status_code (int, optional): The expected status code for a
                successful deletion. Defaults to 204.

        Raises:
            exceptions.DeletionError: If the deletion fails.
        """
        endpoint = f"{self.endpoint}/{object_id}"

        utils.print_log(
            self._logger, f"Calling delete_by_id endpoint: {endpoint}", logging.DEBUG
        )
        self._run_delete_request(endpoint, expected_status_code=expected_status_code)
